@@ -10,12 +10,13 @@ import os
 import sys
 import time
 import traceback
-import types
 
 import click
-
 import requests
+from rich.markup import escape
+
 import SoftLayer
+from SoftLayer.CLI.command import CommandLoader
 from SoftLayer.CLI import environment
 from SoftLayer.CLI import exceptions
 from SoftLayer.CLI import formatting
@@ -33,49 +34,17 @@ DEBUG_LOGGING_MAP = {
 }
 
 PROG_NAME = "slcli (SoftLayer Command-line)"
-VALID_FORMATS = ['table', 'raw', 'json', 'jsonraw']
+VALID_FORMATS = ['table', 'raw', 'json', 'jsonraw', 'csv']
 DEFAULT_FORMAT = 'raw'
 
 if sys.stdout.isatty():
     DEFAULT_FORMAT = 'table'
 
 
-class CommandLoader(click.MultiCommand):
-    """Loads module for click."""
-
-    def __init__(self, *path, **attrs):
-        click.MultiCommand.__init__(self, **attrs)
-        self.path = path
-
-    def list_commands(self, ctx):
-        """List all sub-commands."""
-        env = ctx.ensure_object(environment.Environment)
-        env.load()
-
-        return sorted(env.list_commands(*self.path))
-
-    def get_command(self, ctx, cmd_name):
-        """Get command for click."""
-        env = ctx.ensure_object(environment.Environment)
-        env.load()
-
-        # Do alias lookup (only available for root commands)
-        if len(self.path) == 0:
-            cmd_name = env.resolve_alias(cmd_name)
-
-        new_path = list(self.path)
-        new_path.append(cmd_name)
-        module = env.get_command(*new_path)
-        if isinstance(module, types.ModuleType):
-            return CommandLoader(*new_path, help=module.__doc__ or '')
-        else:
-            return module
-
-
 def get_latest_version():
     """Gets the latest version of the Softlayer library."""
     try:
-        result = requests.get('https://pypi.org/pypi/SoftLayer/json')
+        result = requests.get('https://pypi.org/pypi/SoftLayer/json',  timeout=60)
         json_result = result.json()
         latest = 'v{}'.format(json_result['info']['version'])
     except Exception:
@@ -83,6 +52,13 @@ def get_latest_version():
     return latest
 
 
+CONTEXT_SETTINGS = {
+    "help_option_names": ['--help', '-h'],
+    "auto_envvar_prefix": 'SLCLI',
+    "max_content_width": 999
+}
+
+
 def get_version_message(ctx, param, value):
     """Gets current and latest release versions message."""
     if not value or ctx.resilient_parsing:
@@ -95,19 +71,16 @@ def get_version_message(ctx, param, value):
 
 
 @click.group(help="SoftLayer Command-line Client",
-             epilog="""To use most commands your SoftLayer
-username and api_key need to be configured. The easiest way to do that is to
-use: 'slcli setup'""",
+             epilog="""To use most commands your SoftLayer username and api_key need to be configured.
+The easiest way to do that is to use: 'slcli setup'""",
              cls=CommandLoader,
-             context_settings={'help_option_names': ['-h', '--help'],
-                               'auto_envvar_prefix': 'SLCLI',
-                               'max_content_width': 999})
+             context_settings=CONTEXT_SETTINGS)
 @click.option('--format',
               default=DEFAULT_FORMAT,
               show_default=True,
               help="Output format",
               type=click.Choice(VALID_FORMATS))
-@click.option('--config', '-C',
+@click.option('-C', '--config',
               required=False,
               default=click.get_app_dir('softlayer', force_posix=True),
               show_default=True,
@@ -119,7 +92,7 @@ use: 'slcli setup'""",
               count=True)
 @click.option('--proxy',
               required=False,
-              help="HTTP[S] proxy to be use to make API calls")
+              help="HTTPS or HTTP proxy to be use to make API calls")
 @click.option('--really / --not-really', '-y',
               is_flag=True,
               required=False,
@@ -145,6 +118,7 @@ def cli(env,
     env.skip_confirmations = really
     env.config_file = config
     env.format = format
+    env.set_env_theme(config_file=config)
     env.ensure_client(config_file=config, is_demo=demo, proxy=proxy)
     env.vars['_start'] = time.time()
     logger = logging.getLogger()
@@ -162,7 +136,7 @@ def cli(env,
     env.client.transport = env.vars['_timings']
 
 
-@cli.resultcallback()
+@cli.result_callback()
 @environment.pass_env
 def output_diagnostics(env, result, verbose=0, **kwargs):
     """Output diagnostic information."""
@@ -171,9 +145,9 @@ def output_diagnostics(env, result, verbose=0, **kwargs):
         diagnostic_table = formatting.Table(['name', 'value'])
         diagnostic_table.add_row(['execution_time', '%fs' % (time.time() - START_TIME)])
 
-        api_call_value = []
+        api_call_value = formatting.Table(['API Calls'], title=None, align="left")
         for call in env.client.transport.get_last_calls():
-            api_call_value.append("%s::%s (%fs)" % (call.service, call.method, call.end_time - call.start_time))
+            api_call_value.add_row(["%s::%s (%fs)" % (call.service, call.method, call.end_time - call.start_time)])
 
         diagnostic_table.add_row(['api_calls', api_call_value])
         diagnostic_table.add_row(['version', consts.USER_AGENT])
@@ -184,13 +158,13 @@ def output_diagnostics(env, result, verbose=0, **kwargs):
 
     if verbose > 1:
         for call in env.client.transport.get_last_calls():
-            call_table = formatting.Table(['', '{}::{}'.format(call.service, call.method)])
+            call_table = formatting.Table(['', '{}::{}'.format(call.service, call.method)], align="left")
             nice_mask = ''
             if call.mask is not None:
                 nice_mask = call.mask
-
             call_table.add_row(['id', call.identifier])
-            call_table.add_row(['mask', nice_mask])
+            #  Need to escape this so Rich doesn't think the mask is a tag and hide it.
+            call_table.add_row(['mask', escape(nice_mask)])
             call_table.add_row(['filter', call.filter])
             call_table.add_row(['limit', call.limit])
             call_table.add_row(['offset', call.offset])
