@@ -1,16 +1,16 @@
 """Creates a global IP."""
 # :license: MIT, see LICENSE for more details.
 
+import click
+
 import SoftLayer
 from SoftLayer.CLI import environment
 from SoftLayer.CLI import exceptions
 from SoftLayer.CLI import formatting
 
-import click
 
-
-@click.command()
-@click.option('--ipv6', '--v6', is_flag=True, help='Order a IPv6 IP')
+@click.command(cls=SoftLayer.CLI.command.SLCommand, )
+@click.option('-v6', '--ipv6', is_flag=True, help='Order a IPv6 IP')
 @click.option('--test', help='test order')
 @environment.pass_env
 def cli(env, ipv6, test):
