@@ -7,7 +7,7 @@ import SoftLayer
 from SoftLayer.CLI import environment
 
 
-@click.command()
+@click.command(cls=SoftLayer.CLI.command.SLCommand, )
 @click.argument('key')
 @click.option('--immediate', is_flag=True, help='Immediate cancellation')
 @environment.pass_env
@@ -16,4 +16,7 @@ def cli(env, key, immediate):
 
     licenses = SoftLayer.LicensesManager(env.client)
 
-    env.fout(licenses.cancel_item(key, immediate))
+    item = licenses.cancel_item(key, immediate)
+
+    if item:
+        env.fout("License key: {} was cancelled.".format(key))
