@@ -9,13 +9,9 @@ from SoftLayer.CLI import exceptions
 from SoftLayer.CLI import helpers
 
 
-@click.command()
+@click.command(cls=SoftLayer.CLI.command.SLCommand, )
 @click.argument('identifier')
-@click.option('--wait',
-              default=0,
-              show_default=True,
-              type=click.INT,
-              help="Name of the image")
+@click.option('--wait', default=0, show_default=True, type=click.INT, help="Seconds to wait")
 @environment.pass_env
 def cli(env, identifier, wait):
     """Check if a virtual server is ready."""
