@@ -5,7 +5,6 @@
     :license: MIT, see LICENSE for more details.
 """
 from SoftLayer.CLI import exceptions
-from SoftLayer.CLI import formatting
 from SoftLayer import SoftLayerError
 from SoftLayer import testing
 
@@ -87,13 +86,11 @@ class FileTests(testing.TestCase):
         list_mock.return_value = [
             {'notes': note_mock}
         ]
-        expected_table = formatting.Table(['notes'])
-        expected_table.add_row([expected_reduced_note])
-        expected_output = formatting.format_output(expected_table) + '\n'
         result = self.run_command(['--format', 'table', 'file', 'volume-list', '--columns', 'notes'])
 
         self.assert_no_fail(result)
-        self.assertEqual(expected_output, result.output)
+        self.assertIn(expected_reduced_note, result.output)
+        self.assertNotIn(note_mock, result.output)
 
     @mock.patch('SoftLayer.FileStorageManager.list_file_volumes')
     def test_volume_count(self, list_mock):
@@ -801,3 +798,7 @@ class FileTests(testing.TestCase):
             result = self.run_command(['file', 'snapshot-get-notification-status', '999'])
             self.assert_no_fail(result)
             self.assertIn(expect, result.output)
+
+    def test_volume_options(self):
+        result = self.run_command(['file', 'volume-options'])
+        self.assert_no_fail(result)
