@@ -17,6 +17,7 @@ from SoftLayer.CLI import exceptions
 from SoftLayer.fixtures import SoftLayer_Product_Order
 from SoftLayer import SoftLayerError
 from SoftLayer import testing
+from SoftLayer import utils
 
 
 class ServerCLITests(testing.TestCase):
@@ -40,17 +41,24 @@ class ServerCLITests(testing.TestCase):
                 {
                     "password": "abc123",
                     "username": "root"
-                }
-            ]}]
+                }],
+                'softwareLicense': {
+                    'softwareDescription':
+                        {
+                            'referenceCode': 'CENTOS_7_64',
+                            'version': '7.8 - 64',
+                            'name': 'Centos'
+                        }}}]
         }
         result = self.run_command(['hardware', 'credentials', '12345'])
 
         self.assert_no_fail(result)
-        self.assertEqual(json.loads(result.output),
-                         [{
-                             'username': 'root',
-                             'password': 'abc123'
-                         }])
+        self.assertEqual(json.loads(result.output), [
+            {'Password': 'abc123',
+             'Software': 'Centos',
+             'Username': 'root',
+             'Version': '7.8 - 64'}
+        ])
 
     def test_server_credentials_exception_passwords_not_found(self):
         mock = self.set_mock('SoftLayer_Hardware_Server', 'getObject')
@@ -84,7 +92,13 @@ class ServerCLITests(testing.TestCase):
                 {
                     "hardwareId": 22222,
                     "id": 333333,
-                    "passwords": [{}]
+                    "passwords": [{}],
+                    "softwareLicense": {
+                        "softwareDescription": {
+                            "name": None,
+                            "version": None
+                        }
+                    }
                 }
             ]
         }
@@ -397,8 +411,19 @@ class ServerCLITests(testing.TestCase):
                                    ])
 
         self.assert_no_fail(result)
-        self.assertEqual(json.loads(result.output),
-                         {'id': 98765, 'created': '2013-08-02 15:23:47'})
+        self.assertIn('Warning: Closed soon: TEST00.pod2', result.output)
+        self.assertIn('"id": 98765', result.output)
+
+        result = self.run_command(['--really', 'server', 'create',
+                                   '--size=S1270_8GB_2X1TBSATA_NORAID',
+                                   '--hostname=test',
+                                   '--domain=example.com',
+                                   '--datacenter=mex01',
+                                   '--os=OS_UBUNTU_14_04_LTS_TRUSTY_TAHR_64_BIT',
+                                   ])
+
+        self.assert_no_fail(result)
+        self.assertNotIn('Warning: Closed soon: mex01', result.output)
 
     @mock.patch('SoftLayer.CLI.template.export_to_template')
     def test_create_server_with_export(self, export_mock):
@@ -511,7 +536,7 @@ class ServerCLITests(testing.TestCase):
         result = self.run_command(['server', 'reflash-firmware', '1000'])
 
         self.assert_no_fail(result)
-        self.assertEqual(result.output, "")
+        self.assertEqual(result.output, 'Successfully device firmware reflashed\n')
         self.assert_called_with('SoftLayer_Hardware_Server',
                                 'createFirmwareReflashTransaction',
                                 args=((1, 1, 1)), identifier=1000)
@@ -621,13 +646,13 @@ class ServerCLITests(testing.TestCase):
         mock.return_value = True
         result = self.run_command(['server', 'toggle-ipmi', '--enable', '12345'])
         self.assert_no_fail(result)
-        self.assertEqual(result.output, 'True\n')
+        self.assertEqual(result.output, 'true\n')
 
     def test_toggle_ipmi_off(self):
         mock.return_value = True
         result = self.run_command(['server', 'toggle-ipmi', '--disable', '12345'])
         self.assert_no_fail(result)
-        self.assertEqual(result.output, 'True\n')
+        self.assertEqual(result.output, 'true\n')
 
     def test_bandwidth_hw(self):
         if sys.version_info < (3, 6):
@@ -636,17 +661,17 @@ class ServerCLITests(testing.TestCase):
         self.assert_no_fail(result)
 
         date = '2019-05-20 23:00'
-        # number of characters from the end of output to break so json can parse properly
-        pivot = 157
         # only pyhon 3.7 supports the timezone format slapi uses
         if sys.version_info < (3, 7):
             date = '2019-05-20T23:00:00-06:00'
-            pivot = 166
-        # Since this is 2 tables, it gets returned as invalid json like "[{}][{}]"" instead of "[[{}],[{}]]"
-        # so we just do some hacky string substitution to pull out the respective arrays that can be jsonifyied
 
-        output_summary = json.loads(result.output[0:-pivot])
-        output_list = json.loads(result.output[-pivot:])
+        split_output = []
+        for table in utils.decode_stacked(result.output):
+            split_output.append(table)
+
+        self.assertEqual(len(split_output), 2)
+        output_summary = split_output[0]
+        output_list = split_output[1]
 
         self.assertEqual(output_summary[0]['Average MBps'], 0.3841)
         self.assertEqual(output_summary[1]['Max Date'], date)
@@ -898,18 +923,6 @@ class ServerCLITests(testing.TestCase):
 
         self.assertEqual(result.exit_code, 2)
 
-    def test_get_hardware_guests(self):
-        result = self.run_command(['hw', 'guests', '123456'])
-        self.assert_no_fail(result)
-
-    def test_hardware_guests_empty(self):
-        mock = self.set_mock('SoftLayer_Virtual_Host', 'getGuests')
-        mock.return_value = None
-
-        result = self.run_command(['hw', 'guests', '123456'])
-        self.assertEqual(result.exit_code, 2)
-        self.assertIsInstance(result.exception, exceptions.CLIAbort)
-
     @mock.patch('SoftLayer.CLI.formatting.confirm')
     def test_authorize_hw_no_confirm(self, confirm_mock):
         confirm_mock.return_value = False
@@ -1010,3 +1023,37 @@ class ServerCLITests(testing.TestCase):
     def test_sensor_discrete(self):
         result = self.run_command(['hardware', 'sensor', '100', '--discrete'])
         self.assert_no_fail(result)
+
+    def test_monitoring(self):
+        result = self.run_command(['hardware', 'monitoring', '100'])
+        self.assert_no_fail(result)
+
+    @mock.patch('SoftLayer.CLI.formatting.confirm')
+    def test_check_for_closing(self, confirm_mock):
+        confirm_mock.return_value = True
+        result = self.run_command(['vs', 'create', '--hostname', 'TEST', '--domain', 'TESTING',
+                                   '--flavor', 'B1_2X8X25', '--datacenter', 'ams01', '--os', 'UBUNTU_LATEST'])
+        self.assert_no_fail(result)
+        self.assertIn('Warning: Closed soon: ams01', result.output)
+        result = self.run_command(['vs', 'create', '--hostname', 'TEST', '--domain', 'TESTING',
+                                   '--flavor', 'B1_2X8X25', '--datacenter', 'mex01', '--os', 'UBUNTU_LATEST'])
+        self.assert_no_fail(result)
+        self.assertNotIn('Warning: Closed soon: mex01', result.output)
+
+    def test_notifications(self):
+        result = self.run_command(['hardware', 'notifications', '100'])
+        self.assert_no_fail(result)
+
+    def test_add_notification(self):
+        result = self.run_command(['hardware', 'notification-add', '100', '--users', '123456'])
+        self.assert_no_fail(result)
+
+    def test_notification_delete(self):
+        result = self.run_command(['hardware', 'notification-delete', '100'])
+        self.assert_no_fail(result)
+
+    def test_create_credential(self):
+        result = self.run_command(['hw', 'create-credential', '123456',
+                                   '--username', 'testslcli', '--password', 'test-123456',
+                                   '--notes', 'test slcli', '--system', 'system'])
+        self.assert_no_fail(result)
