@@ -10,6 +10,7 @@ import sys
 from unittest import mock as mock
 
 from SoftLayer.CLI import exceptions
+from SoftLayer.fixtures import SoftLayer_Product_Package
 from SoftLayer.fixtures import SoftLayer_Virtual_Guest as SoftLayer_Virtual_Guest
 from SoftLayer import SoftLayerAPIError
 from SoftLayer import SoftLayerError
@@ -565,6 +566,8 @@ class VirtTests(testing.TestCase):
     @mock.patch('SoftLayer.CLI.formatting.confirm')
     def test_upgrade_disk(self, confirm_mock):
         confirm_mock.return_value = True
+        mock = self.set_mock('SoftLayer_Product_Package', 'getItemPrices')
+        mock.return_value = SoftLayer_Product_Package.getVSDiskItemPrices
         result = self.run_command(['vs', 'upgrade', '100', '--flavor=M1_64X512X100',
                                    '--resize-disk=10', '1', '--resize-disk=10', '2'])
         self.assert_no_fail(result)
@@ -598,6 +601,8 @@ class VirtTests(testing.TestCase):
     @mock.patch('SoftLayer.CLI.formatting.confirm')
     def test_upgrade_with_add_disk(self, confirm_mock):
         confirm_mock.return_value = True
+        mock = self.set_mock('SoftLayer_Product_Package', 'getItemPrices')
+        mock.return_value = SoftLayer_Product_Package.getVSDiskItemPrices
         result = self.run_command(['vs', 'upgrade', '100', '--add-disk=10', '--add-disk=10'])
         self.assert_no_fail(result)
         self.assert_called_with('SoftLayer_Product_Order', 'placeOrder')
@@ -738,7 +743,7 @@ class VirtTests(testing.TestCase):
 
         result = self.run_command(['vs', 'capture', '100', '--name', 'TestName'])
         self.assert_no_fail(result)
-        self.assert_called_with('SoftLayer_Virtual_Guest', 'createArchiveTransaction', identifier=100)
+        self.assert_called_with('SoftLayer_Virtual_Guest', 'createArchiveTemplate', identifier=100)
 
     @mock.patch('SoftLayer.CLI.formatting.no_going_back')
     def test_usage_no_confirm(self, confirm_mock):
@@ -990,3 +995,9 @@ class VirtTests(testing.TestCase):
     def test_notification_delete(self):
         result = self.run_command(['vs', 'notification-delete', '100'])
         self.assert_no_fail(result)
+
+    def test_os_available(self):
+        _mock = self.set_mock('SoftLayer_Product_Package', 'getItems')
+        _mock.return_value = SoftLayer_Product_Package.getItemsOS
+        result = self.run_command(['vs', 'os-available'])
+        self.assert_no_fail(result)
