@@ -744,7 +744,7 @@ class OrderingTests(testing.TestCase):
                 "capacity": "1",
                 "id": 10201,
                 "keyName": "GUEST_CORE_1_DEDICATED",
-        }]
+            }]
 
         item_capacity = self.ordering.get_item_capacity(items, ['GUEST_CORE_1_DEDICATED', 'OS_RHEL_7_X_LAMP_64_BIT'])
 
@@ -761,7 +761,7 @@ class OrderingTests(testing.TestCase):
                 "capacity": "1",
                 "id": 10201,
                 "keyName": "READHEAVY_TIER",
-        }]
+            }]
 
         item_capacity = self.ordering.get_item_capacity(items, ['READHEAVY_TIER', 'STORAGE_SPACE_FOR_2_IOPS_PER_GB'])
 
@@ -779,7 +779,7 @@ class OrderingTests(testing.TestCase):
                 "capacity": "1",
                 "id": 10201,
                 "keyName": "GUEST_CORE_1_DEDICATED",
-        }]
+            }]
 
         item_capacity = self.ordering.get_item_capacity(items, ['INTEL_XEON_2690_2_60', 'BANDWIDTH_20000_GB'])
 
@@ -893,3 +893,11 @@ class OrderingTests(testing.TestCase):
         # Test None-existing price for term
         price_id = self.ordering.get_item_price_id("8", [price2, price1], 37)
         self.assertEqual(None, price_id)
+
+    def test_get_items(self):
+        self.ordering.get_items(123)
+        self.assert_called_with('SoftLayer_Product_Package', 'getItems')
+
+    def test_get_regions(self):
+        self.ordering.get_regions(123)
+        self.assert_called_with('SoftLayer_Product_Package', 'getRegions')
